@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/local/opt/python/bin/python2.7
 
 import os
 import sys
@@ -22,7 +22,7 @@ import oauth2 as oauth
 import feedparser
 import dateutil.parser
 
-__version__ = '0.7.24'
+__version__ = '0.7.25'
 
 #CWD  = os.path.dirname(os.path.realpath(__file__))
 CWD = os.path.join(os.path.expanduser('~'), '.ecog')
@@ -269,23 +269,26 @@ class EcogWiki(object):
         self.client = oauth.Client(consumer, access_token)
 
     def _request(self, url, method='GET', format=None, body='', headers=None):
-        # url
+        # params
         params = {
             'oauth_version': '2.0',
         }
         if format:
             params['_type'] = format
+
+        # headers
+        headers = {} if not isinstance(headers, dict) else headers
+        if method in ("POST", "PUT"):
+            headers.setdefault('Content-Type', 'application/x-www-form-urlencoded')
+        if method in ("PUT", "DELETE"):
+            params['_method'] = method
+
+        # url
         url = to_url(url, params)
         logger.debug('[_request] %s %s', method, url)
         if body:
             logger.debug('[_request] body: %s', body)
 
-        # headers
-        if not isinstance(headers, dict):
-            headers = {}
-        if method in ("POST", "PUT"):
-            headers.setdefault('Content-Type', 'application/x-www-form-urlencoded')
-
         # do the request
         resp, content = self.client.request(url, method, body=body, headers=headers)
         logger.debug('[_request] response: %s', resp)
@@ -328,7 +331,10 @@ class EcogWiki(object):
         })
         try:
             resp, content = self._request(url, format='json', method='PUT', body=data)
-            content = json.loads(content)
+            try:
+                content = json.loads(content)
+            except Exception as e:
+                logger.error('[post] json load error: %s', e)
             return resp, content
         except HTTPError as e:
             logger.error("[post] %d %s", e.code, e.msg)
@@ -531,9 +537,11 @@ if __name__ == '__main__':
             jsondata   = ecog_get(title, format='json')
             revision   = jsondata['revision']
 
-            updated_at_str = jsondata['updated_at']
-            updated_at_utc = dateutil.parser.parse(updated_at_str)              # parse ISO format
-            updated_at     = updated_at_utc.astimezone(dateutil.tz.tzlocal())   # convert to local timezone
+            updated_at = None
+            if jsondata['updated_at']:
+                updated_at_str = jsondata['updated_at']
+                updated_at_utc = dateutil.parser.parse(updated_at_str)              # parse ISO format
+                updated_at     = updated_at_utc.astimezone(dateutil.tz.tzlocal())   # convert to local timezone
 
             safe_title = urllib.quote_plus(title)
             fd, temp_json = tempfile.mkstemp(dir=tempdir, prefix=safe_title+'-', suffix='.json')
@@ -573,11 +581,15 @@ if __name__ == '__main__':
                         return
                     # 5. ask comment
                     if not comment:
-                        diff = difflib.unified_diff(rawbody.splitlines(True),content.splitlines(True), n=0,
-                                fromfile='%s (rev %d)' % (title, revision),
-                                fromfiledate=updated_at.strftime("%Y/%m/%d %H-%M"),
-                                tofile='EDIT', 
-                        )
+                        options = {
+                            'n': 0,
+                            'fromfile': '%s (rev %d)' % (title, revision),
+                            'tofile': 'EDIT', 
+                        }
+                        if updated_at:
+                            options['fromfiledate'] = updated_at.strftime("%Y/%m/%d %H-%M")
+
+                        diff = difflib.unified_diff(rawbody.splitlines(True),content.splitlines(True), **options)
                         for line in diff:
                             output(line, end='')
                         comment = raw_input('comment message (default: written by ecogwiki client): ')
@@ -586,13 +598,22 @@ if __name__ == '__main__':
                     ecog_post = try_auth_on_forbidden(ecog)(ecog.post)
                     resp, result = ecog_post(title, content, revision=revision, comment=comment)
                     logger.debug('[edit] %s', result)
-                    output('updated "%s" to revision %d: %s' % (title, int(result['revision']), resp['location']))
+                    #output('updated "%s" to revision %d: %s' % (title, int(new_revision), resp['location']))
+                    ## 6.1 [GET] check page back
+                    new_revision = ecog_get(title, format='json')['revision']
+                    output('updated "%s" to revision %d' % (title, int(new_revision)))
 
                     # 7. remove temp file on success
                     try:
                         os.remove(temp_rawbody)
+                        logger.debug('[edit] removed %s', temp_rawbody)
                     except OSError as e:
                         logger.error('[edit] failed removing temp rawbody file %s, %s', temp_rawbody, e)
+                    try:
+                        os.remove(temp_rawbody0)
+                        logger.debug('[edit] removed %s', temp_rawbody0)
+                    except OSError as e:
+                        logger.error('[edit] failed removing temp rawbody file %s, %s', temp_rawbody0, e)
 
                     return result
                 except Exception as e:
@@ -604,11 +625,13 @@ if __name__ == '__main__':
             finally:
                 try:
                     os.remove(temp_json)
+                    logger.debug('[edit] removed %s', temp_json)
                 except OSError as e:
                     logger.error('[edit] failed removing temp json file %s (%s)', temp_json, e)
         finally:
             try:
                 os.removedirs(tempdir)
+                logger.debug('[edit] removed %s', tempdir)
             except OSError as e:
                 logger.error('[edit] failed removing temp directory %s, %s', tempdir, e)
 
